@@ -3,7 +3,7 @@ package Template::Plex;
 use strict;
 use warnings;
 
-our $VERSION = 'v0.9.0';
+our $VERSION = 'v0.9.2';
 use feature qw<say refaliasing>;
 no warnings "experimental";
 
@@ -344,12 +344,18 @@ sub prepend_slot {
 
 
 sub inherit {
-	my ($self, $path)=@_;
+	my ($self, $path, $root)=@_;
 	DEBUG and Log::OK::DEBUG and log_debug __PACKAGE__.": Inherit: $path";
 	#If any parent variables have be setup load the parent template
 
 	#Setup the parent. Cached  with path
-	my $p=$self->load($path, $self->args, $self->meta->%*);
+  my %options=$self->meta->%*;
+  if($root){
+    $options{root}=$root;
+  }
+
+  #my $p=$self->load($path, $self->args, $self->meta->%*);
+	my $p=$self->load($path, $self->args, %options);
   #$p->[slots_]={};
 
 	#Add this template to the default slot
@@ -391,7 +397,7 @@ sub render {
 		#Check slots. Slots indicate we need to call the child first
 		if($self->[slots_] and $self->[slots_]->%*){
 			DEBUG and Log::OK::TRACE and log_trace __PACKAGE__.": render: rendering default slot";
-			$self->[default_result_]=$self->[slots_]{default}->render($fields,1);
+			$self->[default_result_]=$self->[slots_]{default}->render($fields,1) if defined $self->[slots_]{default};
 		}
 
 		#now call render on self. This renders non hierarchial templates
